GLuint loadShaders(const char* vertexShaderPath, const char* fragmentShaderPath)
{
    char* vertexShaderCode = readTextFile( vertexShaderPath );
    char* fragmentShaderCode = readTextFile( fragmentShaderPath );

    GLuint vertexShaderID = glCreateShader(GL_VERTEX_SHADER);
	GLuint fragmentShaderID = glCreateShader(GL_FRAGMENT_SHADER);

    GLint result = GL_FALSE;
    int infoLogLength;

    printf("Compiling vertex shader...\n");
    glShaderSource(vertexShaderID, 1, &vertexShaderCode, NULL);
    glCompileShader(vertexShaderID);

    glGetShaderiv(vertexShaderID, GL_COMPILE_STATUS, &result);
    glGetShaderiv(vertexShaderID, GL_INFO_LOG_LENGTH, &infoLogLength);
    if( infoLogLength > 0 )
    {
        char vertexShaderErrorMessage[infoLogLength + 1];
        glGetShaderInfoLog(vertexShaderID, infoLogLength, NULL, &vertexShaderErrorMessage);
        printf("%s\n", &vertexShaderErrorMessage);
    }

    printf("Compiling fragment shader...\n");
    glShaderSource(fragmentShaderID, 1, &fragmentShaderCode, NULL);
    glCompileShader(fragmentShaderID);

    glGetShaderiv(fragmentShaderID, GL_COMPILE_STATUS, &result);
    glGetShaderiv(fragmentShaderID, GL_INFO_LOG_LENGTH, &infoLogLength);
    if( infoLogLength > 0 )
    {
        char fragmentShaderErrorMessage[infoLogLength + 1];
        glGetShaderInfoLog(fragmentShaderID, infoLogLength, NULL, &fragmentShaderErrorMessage);
        printf("%s\n", &fragmentShaderErrorMessage);
    }

    printf("Linking program\n");
    GLuint programID = glCreateProgram();
    glAttachShader(programID, vertexShaderID);
    glAttachShader(programID, fragmentShaderID);
    glLinkProgram(programID);

    glGetProgramiv(programID, GL_LINK_STATUS, &result);
    glGetProgramiv(programID, GL_INFO_LOG_LENGTH, &infoLogLength);
    if( infoLogLength > 0 )
    {
        char programErrorMessage[infoLogLength + 1];
        glGetProgramInfoLog(programID, infoLogLength, NULL, &programErrorMessage);
        printf("%s\n", &programErrorMessage);
    }

    free( vertexShaderCode );
    free( fragmentShaderCode );

    glDetachShader( programID, vertexShaderID );
    glDetachShader( programID, fragmentShaderID );

    glDeleteShader( vertexShaderID );
    glDeleteShader( fragmentShaderID );
    return programID;
}


